# sphinx-click-rst-to-ansi-formatter

Use together with [sphinx-click](https://github.com/click-contrib/sphinx-click) to write
[click](https://github.com/pallets/click) command docstrings using Sphinx reST formatting.

## Documentation

See: [hakonhagland.github.io/sphinx-click-rst-to-ansi-formatter/](https://hakonhagland.github.io/sphinx-click-rst-to-ansi-formatter/index.html)
